/*
 * Copyright (C) 2016 Texas Instruments Incorporated - http://www.ti.com/
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/

//******************************************************************************
// Version history:
// 1.0 07/17             Initial version. (Nima Eskandari)
// 1.1 07/17             Added Comments. (Nima Eskandari)
//----------------------------------------------------------------------------
//   Designed 2017 by Texas Instruments
//
//   Nima Eskandari
//   Texas Instruments Inc.
//   August 2017
//   Built with CCS Version: Code Composer Studio v7
//******************************************************************************

#include <stdio.h>
#include <stdbool.h>
#include <stddef.h>
#include <termios.h>
#include <time.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/types.h>
#include <string.h>

#include "uart_if.h"
#include "config.h"



//*****************************************************************************
// Get delay in milli seconds *************************************************
// time: The number of milliseconds to delay **********************************
//*****************************************************************************
void MsDelay(uint32_t time)
{
	usleep(time*1000);
}

//*****************************************************************************
// Get delay in micro seconds *************************************************
// time: Number of micro seconds to delay *************************************
//*****************************************************************************
void usDelay(uint32_t time)
{
	usleep(time);
}

//*****************************************************************************
// Print an array to console **************************************************
// dataArray: The data array to print *****************************************
// size: The size of the dataArray ********************************************
//*****************************************************************************
void printArray(uint8_t * dataArray, uint16_t size)
{
	int i = 0;
	for (i = 0; i < size; i++)
	{
		printf("0x%X, ", dataArray[i]);
	}
	printf("\n");
}

//*****************************************************************************
// Gets the current time in seconds *******************************************
//*****************************************************************************
int GetTime()
{

    return (int)time(NULL);
}

//*****************************************************************************
// Gets the current time in micro seconds *************************************
//*****************************************************************************
long Get_mS_Time_Diff(struct timespec t_ref)
{
	long msTime;
	struct timespec t_now;

	clock_gettime(CLOCK_MONOTONIC, &t_now);
//	printf("Ref sec: %d, Ref ns: %d\n", t_ref.tv_sec, t_ref.tv_nsec); TOBE removed
//	printf("Now sec: %d, Now ns: %d\n", t_now.tv_sec, t_now.tv_nsec); TOBE removed

	if (t_now.tv_nsec < t_ref.tv_nsec)
	{
		t_now.tv_nsec + 1000000000;
		t_now.tv_sec - 1;
	}

	msTime = ( (t_now.tv_sec - t_ref.tv_sec) * 1000000000 + 
	           (t_now.tv_nsec - t_ref.tv_nsec) ) / 1000000;

    return msTime;
}
